@@ -542,7 +542,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
                 datacard.delete()
             except:
                 pass
-        elif (replace == True and slug != None):
+        elif (replace == True and slug == None):
             print("Please specify a datacard slug to replace!")
             return
 
@@ -1358,6 +1358,22 @@ class Askdata(SignUp):
                 logging.error("{}".format(e.__str__()))
                 logging.error("{} workspace not found".format(workspace))
                 return None
+        elif(workspace != '' and dataset!=''):
+            # Get agent_id and dataset_id
+            try:
+                slug=dataset
+
+                authentication_url = self.base_url+'/smartbot/agents/agentslug/'+workspace + '/datasetslug/' + slug
+
+                headers = {"Authorization": "Bearer" + " " + self._token}
+                response = s.get(url=authentication_url, headers=headers)
+                response.raise_for_status()
+                r = response.json()
+                dataset_id = r["datasetId"]
+            except Exception as e:
+                logging.error("{}".format(e.__str__()))
+                logging.error("{} workspace not found".format(workspace))
+                return None
         else:
             # Get agent_id and dataset_id
             try:
@@ -1377,7 +1393,8 @@ class Askdata(SignUp):
                 return None
 
         agent = self.agent(workspace)
-        qc = agent.create_qc(dataset, fields, filters, sorted_by, limit, offset, pivot)
+        if(fields!=[]):
+            qc = agent.create_qc(dataset, fields, filters, sorted_by, limit, offset, pivot)
 
         url = self.base_url + "/smartbot/agent-slugs/"+workspace+"/v2/ask"
 
@@ -1389,14 +1406,13 @@ class Askdata(SignUp):
         body = {
             "message": query,
             "language": lang.lower(),
-            "metadata":[
-                {
-                    "qc": qc
-                }
-            ],
+            "metadata":[],
             "getRawData": get_raw_data
         }
 
+        if(fields!=[]):
+            body["metadata"].append({"qc": qc})
+
         response = s.post(url=url, json=body, headers=self._headers)
         response.raise_for_status()
         result = response.json()["cards"]
