@@ -150,7 +150,7 @@ class Dataset():
         columnsid = [row['columnId'] for row in entities_df.loc[index_nocust,'schemaMetaData']]
         entitie_code = entities_df.code.tolist()
 
-        #select code of entities with custom = False
+        # select code of entities with custom = False
         if select_custom == False:
             entitie_code = entities_df.loc[index_nocust, 'code'].tolist()
 
@@ -160,7 +160,7 @@ class Dataset():
 
         if dataset_id != '':
             pass
-        elif hasattr(self, '_dataset_slug') != '' and dataset_id == '':
+        elif hasattr(self, '_dataset_slug') is not None and dataset_id == '':
             dataset_id = self._dataset_id
             logging.info("---- sync dataset with id '{}' ----- ".format(str(self._dataset_id)))
         else:
@@ -1089,7 +1089,7 @@ class Dataset():
             self._get_info_dataset_by_slug(dataset_slug)
             logging.debug("---- get info for dataset with slug '{}' ----- ".format(dataset_slug))
 
-        elif hasattr(self,'_dataset_slug') != '' and dataset_slug == '':
+        elif dataset_slug == '':
             pass
             logging.debug("---- get info for dataset with slug '{}' ----- ".format(str(self._dataset_slug)))
         else:
