@@ -300,7 +300,7 @@ class Query:
 
         consistent_datatypes = {"numeric":
                                     ["bit", "smallmoney", "money", "int",
-                                     "decimal", "decimal(4,2)", "float", "float64", "double",
+                                     "decimal", "decimal(4,2)", "decimal(3,2)", "float", "float64", "double",
                                      "bigdecimal", "int32", "int64", "bigint",
                                      "numeric", "bignumeric", "smallint", "integer",
                                      "tinyint", "byteint", "int8", "long",
@@ -382,7 +382,7 @@ class Query:
 
         consistent_datatypes = {"numeric":
                                     ["bit", "smallmoney", "money", "int",
-                                     "decimal", "decimal(4,2)", "float", "float64", "double",
+                                     "decimal", "decimal(4,2)", "decimal(3,2)", "float", "float64", "double",
                                      "bigdecimal", "int32", "int64", "bigint",
                                      "numeric", "bignumeric", "smallint", "integer",
                                      "tinyint", "byteint", "int8", "long",
